summaryrefslogtreecommitdiffstats
path: root/chrome/browser/frame_view.h
diff options
context:
space:
mode:
authorbeng@google.com <beng@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2008-07-30 04:48:39 +0000
committerbeng@google.com <beng@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2008-07-30 04:48:39 +0000
commitf3e99e3d1dd8d37c7d0e37daa24df7717cd7783b (patch)
tree4d46a6020077f2385a8720882e76158ce878f432 /chrome/browser/frame_view.h
parent43a973aeb04b5d0ac64bb730cadf0737de8b0cd9 (diff)
downloadchromium_src-f3e99e3d1dd8d37c7d0e37daa24df7717cd7783b.zip
chromium_src-f3e99e3d1dd8d37c7d0e37daa24df7717cd7783b.tar.gz
chromium_src-f3e99e3d1dd8d37c7d0e37daa24df7717cd7783b.tar.bz2
Rename ChromeFrame->BrowserWindow
Move static utility functions to FrameUtil class. B=1294302 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@102 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/frame_view.h')
-rw-r--r--chrome/browser/frame_view.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/chrome/browser/frame_view.h b/chrome/browser/frame_view.h
index 2ea2c47..18f0b73 100644
--- a/chrome/browser/frame_view.h
+++ b/chrome/browser/frame_view.h
@@ -34,15 +34,15 @@
#include "chrome/views/view.h"
-class ChromeFrame;
+class BrowserWindow;
class OSExchangeData;
// FrameView is the View that contains all the views of the ChromeFrame
// (XPFrame or VistaFrame). FrameView forwards all drag and drop messages to
// the TabStrip.
class FrameView : public ChromeViews::View {
public:
- explicit FrameView(ChromeFrame* frame);
+ explicit FrameView(BrowserWindow* frame);
virtual ~FrameView() {}
// Adds view to the set of views that drops are allowed to occur on. You only
@@ -74,8 +74,8 @@ class FrameView : public ChromeViews::View {
ChromeViews::DropTargetEvent* MapEventToTabStrip(
const ChromeViews::DropTargetEvent& event);
- // The ChromeFrame we're the child of.
- ChromeFrame* frame_;
+ // The BrowserWindow we're the child of.
+ BrowserWindow* window_;
// Initially set in CanDrop by invoking the same method on the TabStrip.
bool can_drop_;
@@ -34,15 +34,15 @@
class OSExchangeData;
-// FrameView is the View that contains all the views of the ChromeFrame
+// FrameView is the View that contains all the views of the BrowserWindow
// (XPFrame or VistaFrame). FrameView forwards all drag and drop messages to
// the TabStrip.